@@ -1,4 +1,5 @@
 import argparse
+
 from anyerplint import __version__
 from anyerplint.cli import check, importcmd
 
@@ -21,7 +22,7 @@ def main() -> None:
 
     check.init_parser(subparsers.add_parser("check", help="Check templates"))
     importcmd.init_parser(
-        subparsers.add_parser("import", help="Import definitions from .zip file")
+        subparsers.add_parser("import", help="Import definitions from .zip file"),
     )
     args = main_parser.parse_args()
     args.func(args)
